@@ -1,6 +1,8 @@
 package Astro::Constants;
 # ABSTRACT: this library provides physical constants for use in Astronomy
-$Astro::Constants::VERSION = '0.10.1';
+$Astro::Constants::VERSION = '0.11_95'; # TRIAL
+
+$Astro::Constants::VERSION = '0.1195';use 5.006;
 use strict;
 use warnings;
 
@@ -18,7 +20,7 @@ Astro::Constants - this library provides physical constants for use in Astronomy
 
 =head1 VERSION
 
-version 0.10.1
+version 0.11_95
 
 =head1 SYNOPSIS
 
@@ -39,6 +41,13 @@ centimetres /grams /seconds
 with B<Astro::Constants::CGS> and metres /kilograms /seconds with
 B<Astro::Constants::MKS>.
 
+The C<:long> tag imports all the constants in their long name forms
+(i.e. GRAVITATIONAL).  Useful subsets can be imported with these tags:
+C<:fundamental> C<:conversion> C<:mathematics> C<:cosmology> 
+C<:planetary> C<:electromagnetic> or C<:nuclear>.
+Alternate names such as LIGHT_SPEED instead of SPEED_LIGHT or HBAR
+instead of H_BAR are imported with C<:alternates>.  I'd like
+to move away from their use, but they have been in the module for years.
 Short forms of the constant names are included to provide backwards
 compatibility with older versions based on Jeremy Bailin's Astroconst
 library and are available through the import tag C<:short>.
@@ -52,7 +61,6 @@ really inlined functions.
 Short name constants are constructed with the age-old idiom of fiddling
 with the symbol table using typeglobs, e.g. C<*PI = \3.14159>,
 and may be slower than the long name constants.
-I<This could do with some benchmarking.>
 
 =head2 Why use this module
 
@@ -215,6 +223,23 @@ trig constant pi
 
 This constant is also available using the short name C<$A_pi>
 
+=head2 FOUR_PI
+
+    12.5663706143592
+
+trig constant pi times 4 (shorthand for some calculations)
+
+This constant is also available using the short name C<$A_4pi>
+as well as the alternate name C<FOURPI> (imported using the :alternate tag for backwards compatibility)
+
+=head2 STERADIAN
+
+    57.2957795130823
+
+a measure of solid angle in square degrees
+
+This constant is also available using the short name C<$A_ster>
+
 =head2 EXP
 
     2.71828182846
@@ -543,9 +568,10 @@ as well as the alternate name C<NEUTRON_MASS> (imported using the :alternate tag
 
 =head2 MASS_HYDROGEN
 
-    1.67372e-24
+    1.6738e-27
 
-mass of Hydrogen atom
+mass of Hydrogen atom --   
+This value is from the IUPAC and is a little smaller than MASS_PROTON + MASS_ELECTRON, but within the uncertainty given here.  The current value is 1.008u +/- 0.0002 derived from a range of terrestrial materials.  If this is for precision work, you had best understand what you're using.  See https://iupac.org/what-we-do/periodic-table-of-elements/
 
 This constant is also available using the short name C<$A_mH>
 as well as the alternate name C<HYDROGEN_MASS> (imported using the :alternate tag for backwards compatibility)
@@ -584,7 +610,14 @@ This is a helper function that rounds a value or list of values to 5 significant
 
 =head2 precision
 
-Currently broken.  It will return in v0.11
+Give this method the string of the constant and it returns the precision or uncertainty
+listed.
+
+  $rel_precision = precision('GRAVITATIONAL');
+  $abs_precision = precision('MASS_EARTH');
+
+At the moment you need to know whether the uncertainty is relative or absolute.
+Looking to fix this in future versions.
 
 =head1 EXPORT
 
@@ -595,43 +628,43 @@ Select from the following tags:
 
 =item *
 
-:long		(use this one to get the most constants)
+C<:long>                (use this one to get the most constants)
 
 =item *
 
-:short
+C<:short>
 
 =item *
 
-:fundamental
+C<:fundamental>
 
 =item *
 
-:conversion
+C<:conversion>
 
 =item *
 
-:mathematics
+C<:mathematics>
 
 =item *
 
-:cosmology
+C<:cosmology>
 
 =item *
 
-:planetary
+C<:planetary>
 
 =item *
 
-:electromagnetic
+C<:electromagnetic>
 
 =item *
 
-:nuclear
+C<:nuclear>
 
 =item *
 
-:alternates
+C<:alternates>
 
 =back
 
@@ -786,7 +819,7 @@ Boyd Duffee <duffee@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Boyd Duffee.
+This software is copyright (c) 2017 by Boyd Duffee.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
